@@ -5,22 +5,17 @@
         "R_CMD","/usr/lib64/R/bin/Rcmd",
         "R_DEFAULT_PACKAGES","",
         "R_DOC_DIR","/usr/share/R/doc",
-        "R_DVIPSCMD","/usr/bin/dvips",
         "R_GZIPCMD","/bin/gzip",
         "R_HOME","/usr/lib64/R",
         "R_INCLUDE_DIR","/usr/share/R/include",
-        "R_LATEXCMD","/usr/bin/latex",
-        "R_LIBRARY_DIR","/home/edd/svn/rinside/pkg.Rcheck",
-        "R_LIBS","/home/edd/svn/rinside/pkg.Rcheck:/home/edd/svn/rinside/pkg.Rcheck:",
+        "R_LIBRARY_DIR","/usr/local/lib/R/site-library",
         "R_LIBS_SITE","/usr/local/lib/R/site-library:/usr/lib/R/site-library:/usr/lib/R/library",
-        "R_LIBS_USER","~/R/x86_64-pc-linux-gnu-library/2.11",
-        "R_MAKEINDEXCMD","/usr/bin/makeindex",
+        "R_LIBS_USER","~/R/x86_64-pc-linux-gnu-library/2.13",
         "R_OSTYPE","unix",
-        "R_PACKAGE_DIR","/home/edd/svn/rinside/pkg.Rcheck/RInside",
+        "R_PACKAGE_DIR","/usr/local/lib/R/site-library/RInside",
         "R_PACKAGE_NAME","RInside",
         "R_PAPERSIZE","letter",
         "R_PAPERSIZE_USER","letter",
-        "R_PDFLATEXCMD","/usr/bin/pdflatex",
         "R_PDFVIEWER","/usr/bin/xdg-open",
         "R_PLATFORM","x86_64-pc-linux-gnu",
         "R_PRINTCMD","/usr/bin/lpr",
@@ -29,7 +24,7 @@
         "R_SHARE_DIR","/usr/share/R/share",
         "R_TEXI2DVICMD","/usr/bin/texi2dvi",
         "R_UNZIPCMD","/usr/bin/unzip",
-        "R_VERSION","2.11.1",
+        "R_VERSION","2.13.0",
         "R_ZIPCMD","/usr/bin/zip",
         NULL
     };
